( cd usr/lib ; rm -rf libdbus-1.so )
( cd usr/lib ; ln -sf libdbus-1.so.3.4.0 libdbus-1.so )
( cd usr/lib ; rm -rf libdbus-1.so.3 )
( cd usr/lib ; ln -sf libdbus-1.so.3.4.0 libdbus-1.so.3 )
#%% begin initialize dbus-1.2.12-i586-P1
dbus-uuidgen --ensure 
#%% end
